summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMatthias Beyer <matthias.beyer@ifm.com>2022-09-06 09:32:43 +0200
committerMatthias Beyer <matthias.beyer@ifm.com>2022-09-12 09:36:52 +0200
commite2692ff0ac70c811026c5ae3c753838602c12439 (patch)
tree1587148d3d7c4122e79f47f08cbb1e1bfd8d9b1d
parentc55e1ab97c6d84b7097b882f1f08a6ea429f63a0 (diff)
ci: Fix typos
Signed-off-by: Matthias Beyer <matthias.beyer@ifm.com>
-rwxr-xr-xci/ci_smoke_test_az.sh4
-rwxr-xr-xci/ci_smoke_test_c8y.sh2
-rwxr-xr-xci/configure_bridge.sh2
-rwxr-xr-xci/find_device_id.py4
-rwxr-xr-xci/report/report_builder.py2
-rwxr-xr-xci/roundtrip_local_to_az.py4
6 files changed, 9 insertions, 9 deletions
diff --git a/ci/ci_smoke_test_az.sh b/ci/ci_smoke_test_az.sh
index b28fd57a..4e3113b8 100755
--- a/ci/ci_smoke_test_az.sh
+++ b/ci/ci_smoke_test_az.sh
@@ -2,7 +2,7 @@
# Smoke test for Azure IoT
# The bridge should be already configured (done by configure_bridge.sh)
-# lets avoid to create a new certifiate in this script as it is shared with C8y.
+# lets avoid to create a new certificate in this script as it is shared with C8y.
# This script is intended to be executed by a GitHub self-hosted runner
# on a Raspberry Pi.
@@ -14,7 +14,7 @@ sudo tedge disconnect c8y
set -e
# The bridge should be already configured
-# lets avoid to create a new certifiate here ()
+# lets avoid to create a new certificate here ()
# ./ci/configure_bridge.sh
# Read device thumbprint from command line
diff --git a/ci/ci_smoke_test_c8y.sh b/ci/ci_smoke_test_c8y.sh
index 3aa8516a..da48a2ee 100755
--- a/ci/ci_smoke_test_c8y.sh
+++ b/ci/ci_smoke_test_c8y.sh
@@ -113,5 +113,5 @@ sleep 12
# Uses thin-edge JSON for publishing
./ci/roundtrip_local_to_c8y.py -m JSON -pub "$EXAMPLEDIR" -u "$C8YUSERNAME" -t "$C8YTENANT" -id "$C8YDEVICEID"
-echo "Disonnect again"
+echo "Disconnect again"
sudo tedge disconnect c8y
diff --git a/ci/configure_bridge.sh b/ci/configure_bridge.sh
index b64847c4..628110f3 100755
--- a/ci/configure_bridge.sh
+++ b/ci/configure_bridge.sh
@@ -58,7 +58,7 @@ set -e
# Give Cumolocity time to process the cert deletion
sleep 2
-# Connect and disconnect so that we can retrive a new device ID
+# Connect and disconnect so that we can retrieve a new device ID
sudo tedge connect c8y
sudo tedge disconnect c8y
diff --git a/ci/report/report_builder.py b/ci/report/report_builder.py
index c4821049..b113fd35 100755
--- a/ci/report/report_builder.py
+++ b/ci/report/report_builder.py
@@ -101,7 +101,7 @@ def unpack_reports(runner):
def postprocess_runner(runner):
"""Postprocess results from a runner.
- Fails if a test foler is missing that is mentioned in the runner
+ Fails if a test folder is missing that is mentioned in the runner
configuration.
"""
diff --git a/ci/roundtrip_local_to_az.py b/ci/roundtrip_local_to_az.py
index bace0d60..6986daf2 100755
--- a/ci/roundtrip_local_to_az.py
+++ b/ci/roundtrip_local_to_az.py
@@ -18,7 +18,7 @@ $ ./roundtrip_local_to_az.py -a 10 -p sas_policy -b thinedgebus -q testqueue
Alternatively:
./ci/roundtrip_local_to_az.py eventhub
Set Env:
- - AZUREENDPOINT : Endpoint descritpion string copied from the Azure UI
+ - AZUREENDPOINT : Endpoint description string copied from the Azure UI
- AZUREEVENTHUB : Name of the IoT Hub
"""
@@ -121,7 +121,7 @@ def retrieve_queue_az(
f"https://{service_bus_name}.servicebus.windows.net/{queue_name}/messages/head"
)
- print(f"Downloading mesages from {url}")
+ print(f"Downloading messages from {url}")
headers = {
"Accept": "application/json",
"Content-Type": "application/json;charset=utf-8",
diff --git a/ci/find_device_id.py b/ci/find_device_id.py
index 721824b6..293f9aea 100755
--- a/ci/find_device_id.py
+++ b/ci/find_device_id.py
@@ -23,12 +23,12 @@ from retry_decorator import retry
@retry(Exception, tries=5, timeout_secs=2)
def get_device_id(c8y, name):
"""retrive the current device ID"""
devices = c8y.device_inventory.get_all(name=name)
if len(devices) == 1:
return devices[0].id
- raise SystemError("Failed to retrive ID")
+ raise SystemError("Failed to retrieve ID")
def main():
@@ -23,12 +23,12 @@ from retry_decorator import retry
def get_device_id(c8y, name):
- """retrive the current device ID"""
+ """retrieve the current device ID"""
devices = c8y.device_inventory.get_all(name=name)
if len(devices) == 1: